==> SugarCE-6.2.0.zip: SugarCE-Full-6.2.0/modules/EAPM/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

$mod_strings = array (
  'LBL_ASSIGNED_TO_ID' => 'Assigned User Id',
  'LBL_ASSIGNED_TO_NAME' => 'Sugar User',
  'LBL_ID' => 'ID',
  'LBL_DATE_ENTERED' => 'Date Created',
  'LBL_DATE_MODIFIED' => 'Date Modified',
  'LBL_MODIFIED' => 'Modified By',
  'LBL_MODIFIED_ID' => 'Modified By Id',
  'LBL_MODIFIED_NAME' => 'Modified By Name',
  'LBL_CREATED' => 'Created By',
  'LBL_CREATED_ID' => 'Created By Id',
  'LBL_DESCRIPTION' => 'Description',
  'LBL_DELETED' => 'Deleted',
  'LBL_NAME' => 'App User Name',
  'LBL_CREATED_USER' => 'Created By User',
  'LBL_MODIFIED_USER' => 'Modified By User',
  'LBL_LIST_NAME' => 'Name',
  'LBL_TEAM' => 'Teams',
  'LBL_TEAMS' => 'Teams',
  'LBL_TEAM_ID' => 'Team Id',
  'LBL_LIST_FORM_TITLE' => 'External Account List',
  'LBL_MODULE_NAME' => 'External Account',
  'LBL_MODULE_TITLE' => 'External Accounts',
  'LBL_HOMEPAGE_TITLE' => 'My External Accounts',
  'LNK_NEW_RECORD' => 'Create External Account',
  'LNK_LIST' => 'View External Accounts',
  'LNK_IMPORT_SUGAR_EAPM' => 'Import External Accounts',
  'LBL_SEARCH_FORM_TITLE' => 'Search External Source',
  'LBL_HISTORY_SUBPANEL_TITLE' => 'View History',
  'LBL_ACTIVITIES_SUBPANEL_TITLE' => 'Activities',
  'LBL_SUGAR_EAPM_SUBPANEL_TITLE' => 'External Accounts',
  'LBL_NEW_FORM_TITLE' => 'New External Account',
  'LBL_PASSWORD' => 'App Password',
  'LBL_USER_NAME' => 'App User Name',
  'LBL_URL' => 'URL',
  'LBL_APPLICATION' => 'Application',
  'LBL_API_DATA' => 'API Data',
  'LBL_API_TYPE' => 'Login Type',
  'LBL_API_CONSKEY' => 'Consumer Key',
  'LBL_API_CONSSECRET' => 'Consumer Secret',
  'LBL_API_OAUTHTOKEN' => 'OAuth Token',
  'LBL_AUTH_UNSUPPORTED' => "This authorization method is not supported by the application",
  'LBL_AUTH_ERROR' => 'The attempt to connect to this account failed.',
  'LBL_VALIDATED' => 'Connected',
  'LBL_ACTIVE' => 'Active',
  'LBL_OAUTH_NAME' => '%s',
  'LBL_SUGAR_USER_NAME' => 'Sugar User',
  'LBL_DISPLAY_PROPERTIES' => 'Display Properties',
  'LBL_CONNECT_BUTTON_TITLE' => 'Connect',
  'LBL_NOTE' => 'Please Note',
  'LBL_CONNECTED' => 'Connected',
  'LBL_DISCONNECTED' => 'Not Connected',

  'LBL_ERR_NO_AUTHINFO' => 'There is no authentication information for this account.',
  'LBL_ERR_NO_TOKEN' => 'There are no valid login tokens for this account.',
  
  'LBL_ERR_FAILED_QUICKCHECK' => 'You are not currently connected to your {0} account. Click OK to login to your account and to re-activate the connection.',

  // Various strings used throughout the external account modules
  'LBL_MEET_NOW_BUTTON' => 'Meet Now',
  'LBL_VIEW_LOTUS_LIVE_MEETINGS' => 'View Upcoming LotusLive&trade; Meetings',
  'LBL_TITLE_LOTUS_LIVE_MEETINGS' => 'Upcoming LotusLive&trade; Meetings',
  'LBL_VIEW_LOTUS_LIVE_DOCUMENTS' => 'View LotusLive&trade; Files',
  'LBL_TITLE_LOTUS_LIVE_DOCUMENTS' => 'LotusLive&trade; Files',
  'LBL_REAUTHENTICATE_LABEL' => 'Reauthenticate',
  'LBL_REAUTHENTICATE_KEY' => 'a',
  'LBL_APPLICATION_FOUND_NOTICE' => 'An account for this application already exists. We have reinstated the existing account.',
  'LBL_OMIT_URL' => '(Omit http:// or https://)',
  'LBL_OAUTH_SAVE_NOTICE' => 'Click <b>Connect</b> to be directed to a page to provide your account information and to authorize access to the account by Sugar. After connecting, you will be directed back to Sugar.',
  'LBL_BASIC_SAVE_NOTICE' => 'Click <b>Connect</b> to connect this account to Sugar.',
  'LBL_ERR_FACEBOOK' => 'Facebook returned an error, and the feed cannot be displayed.',
  'LBL_ERR_NO_RESPONSE' => 'An error occurred when trying to connect to this account.',
  'LBL_ERR_TWITTER' => 'Twitter returned an error, and the feed cannot be displayed.',
  'LBL_ERR_POPUPS_DISABLED' => 'Please enable browser popup windows or add an exception for website "{0}" to the exceptions list in order to connect.'
);

==> SugarCE-6.5.6.zip: SugarCE-Full-6.5.6/modules/EAPM/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2012 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

$mod_strings = array (
  'LBL_ASSIGNED_TO_ID' => 'Assigned User Id',
  'LBL_ASSIGNED_TO_NAME' => 'Sugar User',
  'LBL_ID' => 'ID',
  'LBL_DATE_ENTERED' => 'Date Created',
  'LBL_DATE_MODIFIED' => 'Date Modified',
  'LBL_MODIFIED' => 'Modified By',
  'LBL_MODIFIED_ID' => 'Modified By Id',
  'LBL_MODIFIED_NAME' => 'Modified By Name',
  'LBL_CREATED' => 'Created By',
  'LBL_CREATED_ID' => 'Created By Id',
  'LBL_DESCRIPTION' => 'Description',
  'LBL_DELETED' => 'Deleted',
  'LBL_NAME' => 'App User Name',
  'LBL_CREATED_USER' => 'Created By User',
  'LBL_MODIFIED_USER' => 'Modified By User',
  'LBL_LIST_NAME' => 'Name',
  'LBL_TEAM' => 'Teams',
  'LBL_TEAMS' => 'Teams',
  'LBL_TEAM_ID' => 'Team Id',
  'LBL_LIST_FORM_TITLE' => 'External Account List',
  'LBL_MODULE_NAME' => 'External Account',
  'LBL_MODULE_TITLE' => 'External Accounts',
  'LBL_HOMEPAGE_TITLE' => 'My External Accounts',
  'LNK_NEW_RECORD' => 'Create External Account',
  'LNK_LIST' => 'View External Accounts',
  'LNK_IMPORT_SUGAR_EAPM' => 'Import External Accounts',
  'LBL_SEARCH_FORM_TITLE' => 'Search External Source',
  'LBL_HISTORY_SUBPANEL_TITLE' => 'View History',
  'LBL_ACTIVITIES_SUBPANEL_TITLE' => 'Activities',
  'LBL_SUGAR_EAPM_SUBPANEL_TITLE' => 'External Accounts',
  'LBL_NEW_FORM_TITLE' => 'New External Account',
  'LBL_PASSWORD' => 'App Password',
  'LBL_USER_NAME' => 'App User Name',
  'LBL_URL' => 'URL',
  'LBL_APPLICATION' => 'Application',
  'LBL_API_DATA' => 'API Data',
  'LBL_API_TYPE' => 'Login Type',
  'LBL_API_CONSKEY' => 'Consumer Key',
  'LBL_API_CONSSECRET' => 'Consumer Secret',
  'LBL_API_OAUTHTOKEN' => 'OAuth Token',
  'LBL_AUTH_UNSUPPORTED' => "This authorization method is not supported by the application",
  'LBL_AUTH_ERROR' => 'The attempt to connect to this account failed.',
  'LBL_VALIDATED' => 'Connected',
  'LBL_ACTIVE' => 'Active',
  'LBL_OAUTH_NAME' => '%s',
  'LBL_SUGAR_USER_NAME' => 'Sugar User',
  'LBL_DISPLAY_PROPERTIES' => 'Display Properties',
  'LBL_CONNECT_BUTTON_TITLE' => 'Connect',
  'LBL_NOTE' => 'Please Note',
  'LBL_CONNECTED' => 'Connected',
  'LBL_DISCONNECTED' => 'Not Connected',

  'LBL_ERR_NO_AUTHINFO' => 'There is no authentication information for this account.',
  'LBL_ERR_NO_TOKEN' => 'There are no valid login tokens for this account.',
  
  'LBL_ERR_FAILED_QUICKCHECK' => 'You are not currently connected to your {0} account. Click OK to login to your account and to re-activate the connection.',

  // Various strings used throughout the external account modules
  'LBL_MEET_NOW_BUTTON' => 'Meet Now',
  'LBL_VIEW_LOTUS_LIVE_MEETINGS' => 'View Upcoming IBM SmartCloud&trade; Meetings',
  'LBL_TITLE_LOTUS_LIVE_MEETINGS' => 'Upcoming IBM SmartCloud&trade; Meetings',
  'LBL_VIEW_LOTUS_LIVE_DOCUMENTS' => 'View IBM SmartCloud&trade; Files',
  'LBL_TITLE_LOTUS_LIVE_DOCUMENTS' => 'IBM SmartCloud&trade; Files',
  'LBL_REAUTHENTICATE_LABEL' => 'Reauthenticate',
  'LBL_REAUTHENTICATE_KEY' => 'a',
  'LBL_APPLICATION_FOUND_NOTICE' => 'An account for this application already exists. We have reinstated the existing account.',
  'LBL_OMIT_URL' => '(Omit http:// or https://)',
  'LBL_OAUTH_SAVE_NOTICE' => 'Click <b>Connect</b> to be directed to a page to provide your account information and to authorize access to the account by Sugar. After connecting, you will be directed back to Sugar.',
  'LBL_BASIC_SAVE_NOTICE' => 'Click <b>Connect</b> to connect this account to Sugar.',
  'LBL_ERR_FACEBOOK' => 'Facebook returned an error, and the feed cannot be displayed.',
  'LBL_ERR_NO_RESPONSE' => 'An error occurred when trying to connect to this account.',
  'LBL_ERR_TWITTER' => 'Twitter returned an error, and the feed cannot be displayed.',
  'LBL_ERR_POPUPS_DISABLED' => 'Please enable browser popup windows or add an exception for website "{0}" to the exceptions list in order to connect.'
);
